============
Change Log
============

0.1
============
*1 Feb 2012*

- Initial public release.

0.1.1
------------
*3 Feb 2012*

- Fixed `issue #1 <https://github.com/jessedhillon/pyramid_scss/issues/1>`_: @import could not resolve paths relative to ``asset_path``.

0.2
------------
*19 Feb 2012*

- Fixed `issue #3 <https://github.com/jessedhillon/pyramid_scss/issues/3>`_: caching implementation was incomplete/incorrect.
- Added ``static_path`` configuration for indicating location of static assets.

0.2.2
-----
*30 Jan 2013*

- Complete upload of code that actually fixes `issue #3 <https://github.com/jessedhillon/pyramid_scss/issues/3>`_.

0.3.0
-----
*28 Feb 2013*

- Support pyScss 1.1.5 (code move)
- Fix broken renderer tests (\n issues)
